Stretch
====

Usage: stretch()

Description
-----------

This filter applies resize without autocrop if fit-in option will be not passed in the arguments.

Example
-------

.. image:: images/stretch_before.jpg
    :alt: Picture before the stretch filter

`<http://localhost:8888/unsafe/200x100/filters:stretch()/https://thumbor.readthedocs.io/en/latest/_images/tom_before_brightness.jpg>`_

.. image:: images/stretch_after.jpg
    :alt: Picture after the stretch filter

````